@@ -1,4 +1,4 @@
-# pylint: disable=arguments-differ,missing-function-docstring,missing-class-docstring
+# pylint: disable=arguments-differ,missing-function-docstring,missing-class-docstring,unexpected-keyword-arg,no-value-for-parameter
 
 import tensorflow as tf
 import tensorflow_addons as tfa
@@ -18,7 +18,10 @@ class ClassToken(tf.keras.layers.Layer):
 
     def call(self, inputs):
         batch_size = tf.shape(inputs)[0]
-        cls_broadcasted = tf.broadcast_to(self.cls, [batch_size, 1, self.hidden_size])
+        cls_broadcasted = tf.cast(
+            tf.broadcast_to(self.cls, [batch_size, 1, self.hidden_size]),
+            dtype=inputs.dtype,
+        )
         return tf.concat([cls_broadcasted, inputs], 1)
 
 
@@ -39,7 +42,7 @@ class AddPositionEmbs(tf.keras.layers.Layer):
         )
 
     def call(self, inputs):
-        return inputs + self.pe
+        return inputs + tf.cast(self.pe, dtype=inputs.dtype)
 
 
 class MultiHeadSelfAttention(tf.keras.layers.Layer):
@@ -64,7 +67,7 @@ class MultiHeadSelfAttention(tf.keras.layers.Layer):
     # pylint: disable=no-self-use
     def attention(self, query, key, value):
         score = tf.matmul(query, key, transpose_b=True)
-        dim_key = tf.cast(tf.shape(key)[-1], tf.float32)
+        dim_key = tf.cast(tf.shape(key)[-1], score.dtype)
         scaled_score = score / tf.math.sqrt(dim_key)
         weights = tf.nn.softmax(scaled_score, axis=-1)
         output = tf.matmul(weights, value)
@@ -107,10 +110,14 @@ class TransformerBlock(tf.keras.layers.Layer):
         self.mlpblock = tf.keras.Sequential(
             [
                 tf.keras.layers.Dense(
-                    self.mlp_dim, activation=tfa.activations.gelu, name="Dense_0"
+                    self.mlp_dim,
+                    activation=tf.keras.activations.gelu
+                    if hasattr(tf.keras.activations, "gelu")
+                    else tfa.activations.gelu,
+                    name=f"{self.name}/Dense_0",
                 ),
                 tf.keras.layers.Dropout(self.dropout),
-                tf.keras.layers.Dense(input_shape[-1], name="Dense_1"),
+                tf.keras.layers.Dense(input_shape[-1], name=f"{self.name}/Dense_1"),
                 tf.keras.layers.Dropout(self.dropout),
             ],
             name="MlpBlock_3",
